pub struct Aimd { /* private fields */ }Expand description
Loss-based request rate limiting.
Additive-increase, multiplicative decrease for requests per second.
Increases request rate when:
- no overload errors are observed, and
- requests are successful.
Reduces request rate by a factor when overload is detected.
Implementations
Sourceimpl Aimd
impl Aimd
pub fn new_with_initial_rate(initial_rps: u64) -> Self
pub fn new(initial_rps: u64, rate_range: RangeInclusive<u64>) -> Self
Sourcepub fn decrease_factor(self, factor: f64) -> Self
pub fn decrease_factor(self, factor: f64) -> Self
Set the multiplier which will be applied when decreasing the rate.
Sourcepub fn increase_by(self, increase: u64) -> Self
pub fn increase_by(self, increase: u64) -> Self
Set the increment which will be applied when increasing the rate.
pub fn with_max_rate(self, max: u64) -> Self