pub enum RequestOutcome {
Success,
Overload,
ClientError,
}Expand description
Whether a request succeeded or failed, potentially due to overload.
Errors not considered to be caused by overload should be ignored.
Variants
Success
The request succeeded, or failed in a way unrelated to overload.
Overload
The request failed because of overload, e.g. it timed out or received a 429/503 response.
ClientError
The request failed due to client error (4xx) - not related to rate limiting.